".r)",
".PP",
"All options may be abbreviated;",
"the abbreviation is documented as the upper case letters,",
"all lower case letters and underscores (_) are optional.",
"You must use consecutive sequences of optional letters.",
".PP",
"All options are case insensitive,",
"you may type them in upper case or lower case or a combination of both,",
"case is not important.",
".PP",
"For example:",
"the arguments \\[lq]\\-help\\[rq], \\[lq]\\-HELP\\[rq] and \\[lq]\\-h\\[rq] are",
"all interpreted to mean the \\fB\\-Help\\fP option.",
"The argument \\[lq]-hlp\\[rq] will not be understood,",
"because consecutive optional characters were not supplied.",
".PP",
"Options and other command line arguments may be",
"mixed arbitrarily on the command line,",
"after the function selectors.",
".br",
".ne 4",
".PP",
"The GNU long option names are understood.",
"Since all option names for",
".I \\*(n)",
"are long,",
"this means ignoring the extra leading '-'.",
"The \"\\fB--\\fIoption\\fB=\\fIvalue\\fR\" convention is also understood.",
